@@ -118,13 +118,16 @@ class PluginManager(Callback.Callbacks):
         lname = name.lower()
         return self.active[lname]
 
-    def activate(self, p_info, exclusive=True):
+    def activate(self, p_info, exclusive=None):
         name = p_info.tabname
         lname = p_info.name.lower()
         if lname in self.active:
             # plugin already active
             return
 
+        if exclusive is None:
+            exclusive = p_info.spec.get('exclusive', True)
+
         bnch = Bunch.Bunch(pInfo=p_info, lblname=name, widget=None,
                            exclusive=exclusive)
 
@@ -303,15 +306,17 @@ class PluginManager(Callback.Callbacks):
                 if in_ws.startswith('in:'):
                     # TODO: how to set this size appropriately
                     # Which plugins are actually using this attribute?
-                    vbox.size = (400, 900)
+                    vbox.extdata.size = (400, 900)
 
                 else:
                     # attach size of workspace to container so plugin
                     # can plan for how to configure itself
                     wd, ht = self.ds.get_ws_size(in_ws)
-                    vbox.size = (wd, ht)
+                    vbox.extdata.size = (wd, ht)
 
-                if future:
+                    #vbox.resize(wd, ht)
+
+                if future is not None:
                     p_info.obj.build_gui(vbox, future=future)
                 else:
                     p_info.obj.build_gui(vbox)
