@@ -14,6 +14,7 @@ import ginga.toolkit
 from ginga.util import iohelper
 from ginga.misc import Callback, Bunch
 from ginga.fonts import font_asst
+from ginga import colors
 
 configured = False
 
@@ -423,6 +424,16 @@ def get_icon(iconpath, size=None, adjust_width=True):
     return iconw
 
 
+def get_color(color, alpha):
+    clr = QColor()
+    if isinstance(color, tuple):
+        clr.setRgbF(color[0], color[1], color[2], alpha)
+    else:
+        r, g, b = colors.lookup_color(color)
+        clr.setRgbF(r, g, b, alpha)
+    return clr
+
+
 def get_cached_font(font_name, font_size):
     key = ('qt', font_name, font_size)
     try:
@@ -438,6 +449,7 @@ def get_cached_font(font_name, font_size):
         font = QFont(font_family, font_size)
         font.setStyleStrategy(QFont.PreferAntialias)
         font_asst.add_cache(key, font)
+        return font
 
     except KeyError:
         pass
@@ -445,6 +457,7 @@ def get_cached_font(font_name, font_size):
     # see if we can build the font from the name
     try:
         font = QFont(font_name, font_size)
+        font.setStyleStrategy(QFont.PreferAntialias)
         font_asst.add_cache(key, font)
         return font
 
