@@ -103,7 +103,8 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         # For callbacks
         for name in ('add-image', 'channel-change', 'remove-image',
                      'add-channel', 'delete-channel', 'field-info',
-                     'add-image-info', 'remove-image-info'):
+                     'add-image-info', 'remove-image-info', 'viewer-select',
+                     'delete-workspace'):
             self.enable_callback(name)
 
         # Initialize the timer factory
@@ -232,9 +233,9 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
     # PLUGIN MANAGEMENT
 
     def start_operation(self, opname):
-        return self.start_local_plugin(None, opname, None)
+        return self.start_local_plugin(None, opname)
 
-    def start_local_plugin(self, chname, opname, future):
+    def start_local_plugin(self, chname, opname, future=None):
         channel = self.get_channel(chname)
         opmon = channel.opmon
         opmon.start_plugin_future(channel.name, opname, future)
@@ -1128,7 +1129,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
 
     # CHANNEL MANAGEMENT
 
-    def add_image(self, imname, image, chname=None, silent=False):
+    def add_image(self, imname, image, chname=None, wsname=None, silent=False):
         if chname is None:
             channel = self.get_current_channel()
             if channel is None:
@@ -1136,8 +1137,12 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
                                  "the image")
             chname = channel.name
 
+        if self.has_channel(chname):
+            channel = self.get_channel(chname)
+        else:
+            channel = self.add_channel(chname, workspace=wsname)
+
         # add image to named channel
-        channel = self.get_channel_on_demand(chname)
         channel.add_image(image, silent=silent)
 
     def advertise_image(self, chname, image):
@@ -1428,6 +1433,10 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
             channel = Channel(chname, self, datasrc=None,
                               settings=settings)
 
+            if workspace is not None:
+                if not self.ds.has_ws(workspace):
+                    self.add_workspace(workspace, 'tabs')
+
             bnch = self.add_viewer(chname, settings,
                                    workspace=workspace)
             # for debugging
@@ -1811,7 +1820,15 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
 
         viewer = vinfo.vclass(logger=self.logger,
                               settings=channel.settings)
-        stk_w.add_widget(viewer.get_widget(), title=vinfo.name)
+        if getattr(viewer, 'needs_scrolledview', False):
+            si = Viewers.ScrolledView(viewer)
+            scr_val = 'on'
+            si.scroll_bars(horizontal=scr_val, vertical=scr_val)
+            #scr_set.add_callback('set', self._toggle_scrollbars, si)
+            iw = Widgets.wrap(si)
+            stk_w.add_widget(iw, title=vinfo.name)
+        else:
+            stk_w.add_widget(viewer.get_widget(), title=vinfo.name)
 
         # let the GUI respond to this widget addition
         self.update_pending()
@@ -1849,7 +1866,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         # check general settings for default value of enter_focus
         enter_focus = settings.get('enter_focus', None)
         if enter_focus is None:
-            enter_focus = self.settings.get('enter_focus', True)
+            enter_focus = self.settings.get('enter_focus', False)
         fi.set_enter_focus(enter_focus)
         # check general settings for default value of focus indicator
         focus_ind = settings.get('show_focus_indicator', None)
@@ -2196,6 +2213,8 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         wgts.table.set_tree(tree_dict)
         # highlight first choice
         path = [openers[0].name]
+        text = inspect.getdoc(openers[0].vclass)
+        wgts.descr.set_text(text)
         wgts.table.select_path(path)
 
         dialog = Widgets.Dialog(title="Choose viewer",
@@ -2215,13 +2234,10 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         box.add_widget(wgts.table, stretch=0)
         box.add_widget(wgts.descr, stretch=1)
 
-        ## if mimetype is not None:
-        ##     hbox = Widgets.HBox()
-        ##     wgts.choice = Widgets.CheckBox("Remember choice for session")
-        ##     hbox.add_widget(wgts.choice)
-        ##     box.add_widget(hbox, stretch=0)
-        ## else:
-        ##     wgts.choice = None
+        hbox = Widgets.HBox()
+        wgts.choice = Widgets.CheckBox("Remember choice for session")
+        hbox.add_widget(wgts.choice)
+        box.add_widget(hbox, stretch=0)
 
         self.ds.show_dialog(dialog)
         dialog.resize(600, 600)
@@ -2344,8 +2360,10 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         q_quit.show()
 
     def _confirm_quit_cb(self, w, tf):
-        self.w.quit_dialog.delete()
+        dialog = self.w.quit_dialog
         self.w.quit_dialog = None
+        if dialog is not None:
+            dialog.delete()
         if not tf:
             return
 
@@ -2473,13 +2491,17 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
 
         bnchs = list(sel_dct.values())
         if len(bnchs) != 1:
-            # user didn't select an opener
+            # user didn't select a viewer
             self.show_error("Need to select one viewer!", raisetab=True)
             return
 
         bnch = bnchs[0]
         self.ds.remove_dialog(w)
 
+        if wgts.choice.get_state():
+            # user wants us to remember their choice
+            bnch.priority = -99
+
         open_cb(bnch, dataobj)
         return True
 
@@ -2628,15 +2650,10 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
 
     def workspace_closed_cb(self, ws):
         self.logger.debug("workspace requests close")
-        num_children = ws.num_pages()
-        if num_children > 0:
-            self.show_error(
-                "Please close all windows in this workspace first!",
-                raisetab=True)
-            return
 
         # TODO: this will prompt the user if we should close the workspace
-        lbl = Widgets.Label("Really delete workspace '%s' ?" % (ws.name))
+        lbl = Widgets.Label(f"Really delete workspace '{ws.name}' ?\n\n"
+                            "This will close all open channels in that workspace.")
         dialog = Widgets.Dialog(title="Delete Workspace",
                                 flags=0,
                                 buttons=[['Cancel', 0], ['Ok', 1]],
@@ -2654,6 +2671,16 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         if rsp == 0:
             return
 
+        self.delete_workspace(ws)
+        return True
+
+    def delete_workspace(self, ws):
+        # close all channels in workspace and their plugins
+        for channel in list(self.channel.values()):
+            if channel.workspace == ws.name:
+                self.delete_channel(channel.name)
+
+        # close the workspace
         top_w = ws.extdata.get('top_w', None)
         if top_w is None:
             self.ds.remove_tab(ws.name)
@@ -2664,7 +2691,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         # inform desktop we are no longer tracking this
         self.ds.delete_ws(ws.name)
 
-        return True
+        self.make_gui_callback('delete-workspace', ws)
 
     def page_added_cb(self, ws, child):
         self.logger.debug("page added in %s: '%s'" % (ws.name, str(child)))
@@ -2737,27 +2764,32 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         """
         self._cursor_last_update = time.time()
 
-        try:
-            image = viewer.get_vip()
-            if image.ndim < 2:
-                return
+        if not hasattr(viewer, 'get_vip'):
+            info = Bunch.Bunch(itype='base', data_x=data_x, data_y=data_y,
+                               x=data_x, y=data_y, value=None)
+        else:
+            try:
+                image = viewer.get_vip()
+                if image.ndim < 2:
+                    return
 
-            settings = viewer.get_settings()
-            info = image.info_xy(data_x, data_y, settings)
+                settings = viewer.get_settings()
+                info = image.info_xy(data_x, data_y, settings)
 
-            # Are we reporting in data or FITS coordinates?
-            off = self.settings.get('pixel_coords_offset', 0.0)
-            info.x += off
-            info.y += off
-            if 'image_x' in info:
-                info.image_x += off
-            if 'image_y' in info:
-                info.image_y += off
+                # Are we reporting in data or FITS coordinates?
+                off = self.settings.get('pixel_coords_offset', 0.0)
+                info.x += off
+                info.y += off
+                if 'image_x' in info:
+                    info.image_x += off
+                if 'image_y' in info:
+                    info.image_y += off
 
-        except Exception as e:
-            self.logger.warning(
-                "Can't get info under the cursor: %s" % (str(e)), exc_info=True)
-            return
+            except Exception as e:
+                self.logger.warning(
+                    "Can't get info under the cursor: %s" % (str(e)), exc_info=True)
+                info = Bunch.Bunch(itype='base', data_x=data_x, data_y=data_y,
+                                   x=data_x, y=data_y, value=None)
 
         # TODO: can this be made more efficient?
         chname = self.get_channel_name(viewer)
