@@ -186,7 +186,9 @@ plugins = [
           ptype='local', enabled=True),
     Bunch(module='AutoLoad', workspace='dialogs', category='Utils',
           ptype='local', enabled=False),
-    Bunch(module='Pipeline', workspace='dialogs', category='Utils',
+    Bunch(module='Pipeline', workspace='dialogs', category='Photos',
+          ptype='local', enabled=False),
+    Bunch(module='SlideShow', workspace='dialogs', category='Photos',
           ptype='local', enabled=False),
     Bunch(module='FBrowser', workspace='dialogs', category='Utils',
           ptype='local', enabled=True),
