@@ -36,9 +36,7 @@ import os
 import shutil
 
 # THIRD-PARTY
-import astropy
 from astropy.io import fits
-from astropy.utils.introspection import minversion
 
 # GINGA
 from ginga.GingaPlugin import GlobalPlugin
@@ -412,10 +410,7 @@ class SaveImage(GlobalPlugin):
         self._write_history(key, hdu)
 
         # Write to file
-        if minversion(astropy, '1.3'):
-            hdu.writeto(outfile, overwrite=True)
-        else:
-            hdu.writeto(outfile, clobber=True)
+        hdu.writeto(outfile, overwrite=True)
 
     def _write_mef(self, key, extlist, outfile):
         """Write out regular multi-extension FITS data."""
