@@ -17,7 +17,6 @@ except ImportError:
 from ginga import ImageView, Mixins, Bindings  # noqa
 from ginga.canvas.mixins import DrawingMixin, CanvasMixin, CompoundMixin  # noqa
 from ginga.canvas import render
-from ginga.util.toolbox import ModeIndicator  # noqa
 
 from . import TkHelp  # noqa
 
@@ -450,29 +449,3 @@ class CanvasView(ImageViewZoom):
                                            private_canvas=private_canvas)
 
         self.objects[0] = self.private_canvas
-
-
-class ImageViewCanvasError(ImageViewTkError):
-    pass
-
-
-class ImageViewCanvas(ImageViewZoom,
-                      DrawingMixin, CanvasMixin, CompoundMixin):
-
-    def __init__(self, logger=None, rgbmap=None, settings=None,
-                 bindmap=None, bindings=None):
-        ImageViewZoom.__init__(self, logger=logger,
-                               rgbmap=rgbmap,
-                               settings=settings,
-                               bindmap=bindmap,
-                               bindings=bindings)
-        CompoundMixin.__init__(self)
-        CanvasMixin.__init__(self)
-        DrawingMixin.__init__(self)
-
-        # we are both a viewer and a canvas
-        self.set_canvas(self, private_canvas=self)
-
-        self._mi = ModeIndicator(self)
-
-#END
