@@ -13,7 +13,6 @@ import numpy as np
 
 from ginga import trcalc
 from ginga.misc import Bunch
-from ginga.util.toolbox import PIL_LT_9_1
 
 from . import paths
 
@@ -367,16 +366,10 @@ for path in glob.glob(glob_pat):
                                          path=os.path.abspath(path))
 
 if have_pil_lcms:
-    if PIL_LT_9_1:
-        d = dict(absolute_colorimetric=ImageCms.INTENT_ABSOLUTE_COLORIMETRIC,
-                 perceptual=ImageCms.INTENT_PERCEPTUAL,
-                 relative_colorimetric=ImageCms.INTENT_RELATIVE_COLORIMETRIC,
-                 saturation=ImageCms.INTENT_SATURATION)
-    else:
-        d = dict(absolute_colorimetric=ImageCms.Intent.ABSOLUTE_COLORIMETRIC,
-                 perceptual=ImageCms.Intent.PERCEPTUAL,
-                 relative_colorimetric=ImageCms.Intent.RELATIVE_COLORIMETRIC,
-                 saturation=ImageCms.Intent.SATURATION)
+    d = dict(absolute_colorimetric=ImageCms.Intent.ABSOLUTE_COLORIMETRIC,
+             perceptual=ImageCms.Intent.PERCEPTUAL,
+             relative_colorimetric=ImageCms.Intent.RELATIVE_COLORIMETRIC,
+             saturation=ImageCms.Intent.SATURATION)
     intents.update(d)
 
     # Build transforms for profile conversions for which we have profiles
